@@ -62,10 +62,12 @@ SUFFIXES = {"k": 1e3, "K": 1e3, "M": 1e6, "B": 1e9, "T": 1e12}
 
 MULTIPLICATION_OPERATORS = {" times "}
 
-DIVISION_OPERATORS = {u" per ", u" a "}
+DIVISION_OPERATORS = {" per ", " a "}
 
-GROUPING_OPERATORS = {u",", u" "}
-DECIMAL_OPERATORS = {u"."}
+NEGATIVES = {"minus", "negative"}
+
+GROUPING_OPERATORS = {",", " "}
+DECIMAL_OPERATORS = {"."}
 
 # Pattern for extracting word based numbers
 TEXT_PATTERN = r"""            # Pattern for extracting mixed digit-spelled num
@@ -79,8 +81,10 @@ TEXT_PATTERN = r"""            # Pattern for extracting mixed digit-spelled num
                                       # number
 """
 
-RANGES = {"to", "and"}
-UNCERTAINTIES = {"plus minus"}
+RANGES = {"to"}  # "and" in "between X and" will be converted to "to".
+UNCERTAINTIES = {"plus minus", "plus or minus"}
+
+CONJUNCTIONS = {"and", "or", "but"}
 
 POWERS = {"squared": 2, "cubed": 3}
 EXPONENTS_REGEX = r"(?:(?:\^?\-?[0-9{{superscripts}}]+)?(?:\ (?:{powers}))?)".format(
