@@ -9,19 +9,20 @@ from . import no_classifier as no_clf
 
 
 ###############################################################################
-def disambiguate_unit(unit_surface, text, lang="en_US"):
+def disambiguate_unit(unit_surface, text, lang="en_US", classifier_path=None):
     """
     Resolve ambiguity between units with same names, symbols or abbreviations.
     :returns (str) unit name of the resolved unit
     """
     if clf.USE_CLF:
-        base = clf.disambiguate_unit(unit_surface, text, lang).name
+        base = clf.disambiguate_unit(unit_surface, text, lang, classifier_path).name
     else:
+        units_ = load.units(lang)
         base = (
-            load.units(lang).symbols[unit_surface]
-            or load.units(lang).surfaces[unit_surface]
-            or load.units(lang).surfaces_lower[unit_surface.lower()]
-            or load.units(lang).symbols_lower[unit_surface.lower()]
+            units_.symbols[unit_surface]
+            or units_.surfaces[unit_surface]
+            or units_.surfaces_lower[unit_surface.lower()]
+            or units_.symbols_lower[unit_surface.lower()]
         )
 
         if len(base) > 1:
@@ -38,18 +39,21 @@ def disambiguate_unit(unit_surface, text, lang="en_US"):
 
 
 ###############################################################################
-def disambiguate_entity(key, text, lang="en_US"):
+def disambiguate_entity(key, text, lang="en_US", classifier_path=None):
     """
     Resolve ambiguity between entities with same dimensionality.
     """
+
+    entities_ = load.entities(lang)
+
     try:
         if clf.USE_CLF:
-            ent = clf.disambiguate_entity(key, text, lang)
+            ent = clf.disambiguate_entity(key, text, lang, classifier_path)
         else:
-            derived = load.entities().derived[key]
+            derived = entities_.derived[key]
             if len(derived) > 1:
                 ent = no_clf.disambiguate_no_classifier(derived, text, lang)
-                ent = load.entities().names[ent]
+                ent = entities_.names[ent]
             elif len(derived) == 1:
                 ent = next(iter(derived))
             else:
